[Asterisk-cvs] asterisk/include/asterisk pbx.h,1.52,1.53

kpfleming kpfleming
Tue Sep 13 18:01:09 CDT 2005


Update of /usr/cvsroot/asterisk/include/asterisk
In directory mongoose.digium.com:/tmp/cvs-serv29439/include/asterisk

Modified Files:
	pbx.h 
Log Message:
check call limit in ast_pbx_start(), instead of waiting until background thread has been launched (needed for issue #5131)


Index: pbx.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/pbx.h,v
retrieving revision 1.52
retrieving revision 1.53
diff -u -d -r1.52 -r1.53
--- pbx.h	30 Aug 2005 18:32:09 -0000	1.52
+++ pbx.h	13 Sep 2005 21:59:45 -0000	1.53
@@ -206,21 +206,27 @@
  */
 struct ast_context *ast_context_find(const char *name);
 
+enum ast_pbx_result {
+	AST_PBX_SUCCESS = 0,
+	AST_PBX_FAILED = -1,
+	AST_PBX_CALL_LIMIT = -2,
+};
+
 /*! Create a new thread and start the PBX (or whatever) */
 /*!
  * \param c channel to start the pbx on
- * Starts a pbx thread on a given channel
- * It returns -1 on failure, and 0 on success
+ * \return Zero on success, non-zero on failure
  */
-int ast_pbx_start(struct ast_channel *c);
+enum ast_pbx_result ast_pbx_start(struct ast_channel *c);
 
 /*! Execute the PBX in the current thread */
 /*!
  * \param c channel to run the pbx on
  * This executes the PBX on a given channel.  It allocates a new
  * PBX structure for the channel, and provides all PBX functionality.
  */
-int ast_pbx_run(struct ast_channel *c);
+enum ast_pbx_result ast_pbx_run(struct ast_channel *c);
 
 /*! 
  * \param context context to add the extension to
@@ -206,21 +206,27 @@
 /*!
  * \param c channel to run the pbx on
- * This executes the PBX on a given channel.  It allocates a new
+ * \return Zero on success, non-zero on failure
+ * This executes the PBX on a given channel. It allocates a new
  * PBX structure for the channel, and provides all PBX functionality.
  */




More information about the svn-commits mailing list